/* $Cambridge: hermes/src/prayer/session/prayer_session.h,v 1.5 2010/07/08 10:20:42 dpc22 Exp $ */
/************************************************
 *    Prayer - a Webmail Interface              *
 ************************************************/

/* Copyright (c) University of Cambridge 2000 - 2008 */
/* See the file NOTICE for conditions of use and distribution. */

/* System header files needed by other headers */

#include <stdio.h>
#include <stdlib.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <stdarg.h>
#include <time.h>
#include <ctype.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>
#include <sys/wait.h>
#include <syslog.h>
#include <pwd.h>
#include <grp.h>
#include <netdb.h>

extern int errno;               /* just in case */

#include "c-client.h"

#include "shared.h"

#include "session.h"
#include "session_streams.h"
#include "addr.h"
#include "ml.h"
#include "mm.h"
#include "mc.h"
#include "stream.h"
#include "folderlist.h"
#include "html_secure.h"
#include "html_secure_tidy.h"
#include "draft.h"
#include "msg.h"
#include "msgmap.h"
#include "speller.h"

#include "abook.h"
#include "lookup.h"
#include "role.h"
#include "dictionary.h"
#include "display.h"
#include "prefs.h"
#include "options.h"
#include "rfc1522.h"
#include "favourite.h"
#include "filter.h"
#include "sieve.h"
#include "account.h"
#include "account_msshell.h"
#include "account_sieve.h"
#include "account_support.h"
#include "checksum.h"
#include "wrap.h"
#include "utf8_calc.h"
